@@ -17,11 +17,11 @@ Log::Abstraction - Logging Abstraction Layer
 
 =head1 VERSION
 
-0.10
+0.11
 
 =cut
 
-our $VERSION = 0.10;
+our $VERSION = 0.11;
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ The following arguments can be provided:
 
 If set to 1,
 and C<logger> is not given,
-call C<Carp:carp>.
+call C<Carp:carp> on C<warn()>.
 
 =item * C<config_file>
 
@@ -154,7 +154,7 @@ sub new {
 		# Determine script name
 		$args{'script_name'} = File::Basename::basename($ENV{'SCRIPT_NAME'} || $0);
 
-		# croak(__PACKAGE__, ' syslog needs to know the script name');
+		croak(__PACKAGE__, ' syslog needs to know the script name') if(!defined($args{'script_name'}));
 	}
 
 	if(!defined($args{logger})) {
@@ -165,10 +165,10 @@ sub new {
 	}
 
 	my $self = {
-		messages => [],  # Initialize messages array
+		messages => [],	# Initialize messages array
 		%args,
 	};
-	return bless $self, $class;  # Bless and return the object
+	return bless $self, $class;	# Bless and return the object
 }
 
 # Internal method to log messages. This method is called by other logging methods.
@@ -210,7 +210,7 @@ sub _log {
 				print $fout uc($level), ': ', blessed($self) || __PACKAGE__, ' ', (caller(1))[1], (caller(1))[2], ' ', join('', @messages), "\n";
 				close $fout;
 			}
-		} elsif($logger->can($level)) {
+		} elsif(Scalar::Util::blessed($logger) && ($logger->can($level))) {
 			# If logger is an object, call the appropriate method on the object
 			# The test is because Log::Log4perl doesn't understand notice()
 			$logger->$level(@messages);
@@ -322,8 +322,10 @@ sub warn {
 		};
 		my $err = $@;
 		closelog();
-		if($err)  {
+		if($err) {
 			Carp::carp($err);
+		} elsif($self->{'carp_on_warn'}) {
+			Carp::carp($warning);
 		}
 	} elsif($self->{'carp_on_warn'} || !defined($self->{logger})) {
 		# Fallback to Carp if no logger or syslog is defined
